@@ -16,11 +16,13 @@ from ..common import (
     compute_ament_cmake_python_path,
     sort_packages,
     get_build_var,
+    query_dpkg_architecture,
 )
 
 # command line identation
 cmdind = "    "
 destdirs = set()
+dpkg_info = query_dpkg_architecture()
 
 
 def prepare_argparse():
@@ -285,13 +287,23 @@ def do_action(action, args, path, package, buildopts, install_prefix, environ):
         pythonpaths += compute_python_package_path(install_prefix)
     env["PYTHONPATH"] = ":".join(pythonpaths)
 
+    deb_host_multiarch = dpkg_info.get("DEB_HOST_MULTIARCH", "")
+    deb_build_multiarch = dpkg_info.get("DEB_BUILD_MULTIARCH", "")
+    if (
+        "_PYTHON_SYSCONFIGDATA_NAME" not in env
+        and deb_host_multiarch != deb_build_multiarch
+    ):
+        deb_host_arch_os = dpkg_info.get("DEB_HOST_ARCH_OS", "")
+        env["_PYTHON_SYSCONFIGDATA_NAME"] = (
+            f"_sysconfigdata__{deb_host_arch_os}_{deb_host_multiarch}"
+        )
+
     if build_type == "catkin":
         cpath = env.get("CPATH", None)
         cpath = cpath.split(":") if cpath is not None else []
-        deb_host_multiarch = env.get("DEB_HOST_MULTIARCH", None)
         for d in destdirs:
             cpath.append(str(d / "usr" / "include"))
-            if deb_host_multiarch is not None:
+            if deb_host_multiarch:
                 cpath.append(str(d / "usr" / "include" / deb_host_multiarch))
         env["CPATH"] = ":".join(cpath)
 
